@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Breadcrumb - render a breadcrumb trail
 
 =head1 VERSION
 
-Version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -53,6 +53,7 @@ use Tickit::Utils qw(textwidth);
 use List::Util qw(sum0);
 
 use constant CAN_FOCUS => 1;
+use constant WIDGET_PEN_FROM_STYLE => 1;
 use constant KEYPRESSES_FROM_STYLE => 1;
 
 BEGIN {
@@ -83,6 +84,8 @@ Instantiate. The following named parameters may be of use:
 =item * item_transformations - a coderef or arrayref of transformations to
 apply to items received from the adapter.
 
+=item * skip_first - number of items to skip at the start when rendering, default 0
+
 =back
 
 An example of transformations:
@@ -101,10 +104,12 @@ sub new {
 	my $class = shift;
 	my %args = @_;
 	my $transform = delete $args{item_transformations};
+	my $skip = delete $args{skip_first};
 	$transform ||= [];
 	$transform  = [$transform] if ref $transform eq 'CODE';
 	my $self = $class->SUPER::new(%args);
 	$self->{item_transformations} = $transform;
+	$self->{skip_first} = $skip // 0;
 	$self
 }
 
@@ -163,6 +168,7 @@ sub render_item {
 	my $pen = $self->get_style_pen(
 		$order->[1 + ($idx <=> $self->highlight)]
 	);
+#	warn "Item at $idx is ". $self->{crumbs}[$idx] . "\n";
 	$rb->text_at(0, $self->item_col($idx), $self->{crumbs}[$idx], $pen);
 }
 }
@@ -254,11 +260,15 @@ sub update_crumbs {
 	my ($self) = @_;
 	$self->adapter->all->on_done(sub {
 		my $data = shift;
-		$self->{crumbs} = [ map $self->transform_item($_), @$data ];
+		my @copy = @$data;
+		splice @copy, 0, $self->skip_first if $self->skip_first;
+		$self->{crumbs} = [ map $self->transform_item($_), @copy ];
 		$self->window->expose if $self->window;
 	});
 }
 
+sub skip_first { shift->{skip_first} }
+
 =head2 transform_item
 
 Applies any transformations to the given item.
@@ -293,11 +303,12 @@ $self to allow for method chaining.
 sub adapter {
 	my $self = shift;
 	return $self->{adapter} if $self->{adapter} && !@_;
+
 	my ($adapter) = @_;
 
 	if(my $old = delete $self->{adapter}) {
 		$old->bus->unsubscribe_from_event(
-			@{$self->{adapter_subscriptions}}
+			splice @{$self->{adapter_subscriptions}}
 		);
 	}
 	$adapter ||= Adapter::Async::OrderedList::Array->new;
@@ -380,4 +391,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2015. Licensed under the same terms as Perl itself.
